@@ -107,7 +107,8 @@ class BaseMeta(type):
 
         """
         if isinstance(value, Field):
-            value.name = key
+            if value.name is None:
+                value.name = key
             cls._define_fields(key)
         elif isinstance(value, Association):
             value.id = key
@@ -167,6 +168,7 @@ class BaseMeta(type):
         class_name = name[-1]
         if len(name) == 2:
             namespace = name[0]
+            cls._auto_import(namespace)
 
         if cls.defined_models.has_key(class_name):
             classes = copy(cls.defined_models[class_name])
@@ -182,6 +184,17 @@ class BaseMeta(type):
         else:
             return []
 
+    def _auto_import(cls, package):
+        """
+        Tries to import package by absolute path.  Fails silently on failure.
+
+        """
+        try:
+            # Do an import Force absolute imports
+            __import__(package, globals(), locals(), [], 0)
+        except ImportError, err:
+            pass
+
     def get_docstring(cls):
         doc_parts = []
         if cls._docstring:
@@ -367,7 +380,7 @@ class Base(object):
 
     __metaclass__ = BaseMeta
 
-    def __init__(self, fields={}, new_record=True, **kwargs):
+    def __init__(self, fields=None, new_record=True, **kwargs):
         """
         Initialize a new pyperry object with specified fields
 
@@ -377,13 +390,23 @@ class Base(object):
         also use C{kwargs} to specify the fields.
 
         @param fields: dictionary of fields to set on the new instance
-        @param new_record: set new_record flag to C{True} or C{False}.
+        @param new_record: set new_record flag to C{True} or C{False} (this is
+        an internal param and shouldn't be set directly unless you know what
+        you're doing).
 
         """
-        self.fields = {}
-        self.set_fields(fields)
-        self.set_fields(kwargs)
+        if fields is None:
+            fields = {}
+        fields.update(kwargs)
+
+        self.fields = self.default_fields()
         self.new_record = new_record
+
+        if self.new_record:
+            self.set_fields(fields)
+        else:
+            self.set_raw_fields(fields)
+
         self.saved = None
         self.errors = {}
         self._frozen = False
@@ -476,11 +499,39 @@ class Base(object):
     #}
 
     #{ Persistence
+    def default_fields(self):
+        """
+        Return a dict of fields and their default values.
+
+        Only lists non-None defaults.
+
+        """
+        defaults = {}
+        for field_name in self.defined_fields:
+            field = getattr(self.__class__, field_name)
+            if field.default is not None:
+                defaults[field_name] = field.default
+        return defaults
+
+
     def set_fields(self, fields=None, **kwargs):
         """
         Set the fields of the object using the provided dictionary.
 
-        Only fields listed in _defined_fields will be set.
+        Only fields listed in _defined_fields will be set.  This method will
+        route all setting through the Field construct, and is equivalent to
+        setting each key to the equivalent attribute on the class::
+
+            # This is equivalent:
+            for field in fields:
+                setattr(object, field, fields[field])
+
+            # To this (except safety checks):
+            object.set_fields(fields)
+
+        Note:  Keys for fields that are not defined will simply be ignored
+        Also Note: Associations can be set through this method and BelongsTo
+        associations when set will also set the associated foreign_key field.
 
         @param fields: dictionary of fields
 
@@ -489,10 +540,40 @@ class Base(object):
             fields = {}
         fields.update(kwargs)
 
-        for field in fields.keys():
+        for field in fields:
+            if (field in self.defined_fields
+                    or field in self.defined_associations):
+                setattr(self, field, fields[field])
+
+    def set_raw_fields(self, fields=None, **kwargs):
+        """
+        Set the raw fields dict of the object using the provided dictionary.
+
+        Like set_fields, only fields listed in _defined_fields will be set.
+        This method will bypass all logic in the Field instance class and is
+        the same as setting each key in `fields` via the subscript operator::
+
+            # This is equivalent
+            for field in fields:
+                object[field] = fields[field]
+
+            # To this (except safety checks):
+            object.set_raw_fields(fields)
+
+        Note:  Keys for fields that are not defined will simply be ignored
+
+        @param fields: dictionary of fields
+
+        """
+        if fields is None:
+            fields = {}
+        fields.update(kwargs)
+
+        for field in fields:
             if field in self.defined_fields:
                 self[field] = fields[field]
 
+
     def save(self):
         """
         Save the current value of the model's data fields through the write
@@ -522,6 +603,42 @@ class Base(object):
         self.last_writer_response = self.writer(model=self, mode='write')
         return self.last_writer_response.success
 
+    def update(self):
+        """
+        Save the record if it is not a new_record and raise PersistenceError
+        otherwise.
+
+        This will call %L{save()} if the record is not a %C{new_record} and
+        raise a PersistenceError exception otherwise.
+
+        @return: Returns C{True} on success or C{False} on failure
+
+        """
+        if self.new_record:
+            raise errors.PersistenceError(
+                    "update() must only be called on an existing record but "
+                    "new_record attribute is True" )
+
+        return self.save()
+
+    def create(self):
+        """
+        Save the record iff it is a new_record and raise PersistenceError
+        otherwise.
+
+        This will call %L{save()} if the record is a %C{new_record} and
+        raise a PersistenceError exception otherwise.
+
+        @return: Returns C{True} on success or C{False} on failure
+
+        """
+        if self.new_record:
+            raise errors.PersistenceError(
+                    "update() must only be called on a new record but "
+                    "new_record attribute is False" )
+
+        return self.save()
+
     def update_fields(self, fields=None, **kwargs):
         """
         Update the fields with the given dictionary or keywords and save
